@@ -15,6 +15,7 @@ from function_scheduling_distributed_framework.factories.consumer_factory import
 # noinspection PyUnresolvedReferences
 from function_scheduling_distributed_framework.utils import nb_print, patch_print, LogManager, get_logger, LoggerMixin
 from function_scheduling_distributed_framework.timing_job import fsdf_background_scheduler, timing_publish_deco
+from function_scheduling_distributed_framework.function_result_web import app as function_result_web_app
 
 # 有的包默认没加handlers，原始的日志不漂亮且不可跳转不知道哪里发生的。这里把warnning级别以上的日志默认加上handlers。
 nb_log.get_logger(name=None, log_level_int=30, log_filename='pywarning.log')
@@ -125,6 +126,8 @@ class IdeAutoCompleteHelper(LoggerMixin):
 
         self.start_consuming_message = self.consume = self.start = self.consumer.start_consuming_message
 
+        self.clear_filter_tasks = self.consumer.clear_filter_tasks
+
     def multi_process_consume(self, process_num=1):
         run_consumer_with_multi_process(self.consuming_func_decorated, process_num)
 
@@ -248,6 +251,8 @@ def task_deco(queue_name, *, function_timeout=0,
         func.start_consuming_message = func.consume = func.start = consumer.start_consuming_message
         func.multi_process_start = func.multi_process_consume = partial(run_consumer_with_multi_process, func)
 
+        func.clear_filter_tasks = consumer.clear_filter_tasks
+
         # @wraps(func)
         # def __deco(*args, **kwargs):  # 这样函数的id变化了，导致win在装饰器内部开多进程不方便。
         #     return func(*args, **kwargs)
